==> libkgapi-21.04.0-1-armv6h.pkg.tar.xz: usr/lib/cmake/KPimGAPI/KPimGAPITargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim::GAPIBlogger" for configuration ""
set_property(TARGET KPim::GAPIBlogger APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIBlogger PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIBlogger.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIBlogger.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIBlogger )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIBlogger "${_IMPORT_PREFIX}/lib/libKPimGAPIBlogger.so.5.17.0" )

# Import target "KPim::GAPICalendar" for configuration ""
set_property(TARGET KPim::GAPICalendar APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPICalendar PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPICalendar.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPICalendar.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPICalendar )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPICalendar "${_IMPORT_PREFIX}/lib/libKPimGAPICalendar.so.5.17.0" )

# Import target "KPim::GAPIContacts" for configuration ""
set_property(TARGET KPim::GAPIContacts APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIContacts PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Xml;Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIContacts.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIContacts.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIContacts )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIContacts "${_IMPORT_PREFIX}/lib/libKPimGAPIContacts.so.5.17.0" )

# Import target "KPim::GAPICore" for configuration ""
set_property(TARGET KPim::GAPICore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPICore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network;KF5::Wallet"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPICore.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPICore.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPICore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPICore "${_IMPORT_PREFIX}/lib/libKPimGAPICore.so.5.17.0" )

# Import target "KPim::GAPIDrive" for configuration ""
set_property(TARGET KPim::GAPIDrive APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIDrive PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIDrive.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIDrive.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIDrive )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIDrive "${_IMPORT_PREFIX}/lib/libKPimGAPIDrive.so.5.17.0" )

# Import target "KPim::GAPILatitude" for configuration ""
set_property(TARGET KPim::GAPILatitude APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPILatitude PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPILatitude.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPILatitude.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPILatitude )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPILatitude "${_IMPORT_PREFIX}/lib/libKPimGAPILatitude.so.5.17.0" )

# Import target "KPim::GAPIMaps" for configuration ""
set_property(TARGET KPim::GAPIMaps APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIMaps PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIMaps.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIMaps.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIMaps )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIMaps "${_IMPORT_PREFIX}/lib/libKPimGAPIMaps.so.5.17.0" )

# Import target "KPim::GAPITasks" for configuration ""
set_property(TARGET KPim::GAPITasks APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPITasks PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPITasks.so.5.17.0"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPITasks.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPITasks )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPITasks "${_IMPORT_PREFIX}/lib/libKPimGAPITasks.so.5.17.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libkgapi-21.08.2-1-armv6h.pkg.tar.xz: usr/lib/cmake/KPimGAPI/KPimGAPITargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim::GAPIBlogger" for configuration ""
set_property(TARGET KPim::GAPIBlogger APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIBlogger PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIBlogger.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIBlogger.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIBlogger )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIBlogger "${_IMPORT_PREFIX}/lib/libKPimGAPIBlogger.so.5.18.2" )

# Import target "KPim::GAPICalendar" for configuration ""
set_property(TARGET KPim::GAPICalendar APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPICalendar PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPICalendar.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPICalendar.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPICalendar )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPICalendar "${_IMPORT_PREFIX}/lib/libKPimGAPICalendar.so.5.18.2" )

# Import target "KPim::GAPIContacts" for configuration ""
set_property(TARGET KPim::GAPIContacts APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIContacts PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIContacts.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIContacts.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIContacts )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIContacts "${_IMPORT_PREFIX}/lib/libKPimGAPIContacts.so.5.18.2" )

# Import target "KPim::GAPICore" for configuration ""
set_property(TARGET KPim::GAPICore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPICore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::Wallet"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPICore.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPICore.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPICore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPICore "${_IMPORT_PREFIX}/lib/libKPimGAPICore.so.5.18.2" )

# Import target "KPim::GAPIDrive" for configuration ""
set_property(TARGET KPim::GAPIDrive APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIDrive PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIDrive.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIDrive.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIDrive )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIDrive "${_IMPORT_PREFIX}/lib/libKPimGAPIDrive.so.5.18.2" )

# Import target "KPim::GAPILatitude" for configuration ""
set_property(TARGET KPim::GAPILatitude APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPILatitude PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPILatitude.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPILatitude.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPILatitude )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPILatitude "${_IMPORT_PREFIX}/lib/libKPimGAPILatitude.so.5.18.2" )

# Import target "KPim::GAPIMaps" for configuration ""
set_property(TARGET KPim::GAPIMaps APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPIMaps PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPIMaps.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPIMaps.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPIMaps )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPIMaps "${_IMPORT_PREFIX}/lib/libKPimGAPIMaps.so.5.18.2" )

# Import target "KPim::GAPITasks" for configuration ""
set_property(TARGET KPim::GAPITasks APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KPim::GAPITasks PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKPimGAPITasks.so.5.18.2"
  IMPORTED_SONAME_NOCONFIG "libKPimGAPITasks.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KPim::GAPITasks )
list(APPEND _IMPORT_CHECK_FILES_FOR_KPim::GAPITasks "${_IMPORT_PREFIX}/lib/libKPimGAPITasks.so.5.18.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
